PatternMatcher class

Constructors

PatternMatcher(String pattern, {required String workingDirectory, required bool caseSensitive})

Properties

caseSensitive bool
getter/setter pair
directoryParts int
the no. of directories in the pattern
latefinal
hashCode int
The hash code for this object.
no setterinherited
pattern String
getter/setter pair
regEx RegExp
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workingDirectory String
getter/setter pair

Methods

buildRegEx() RegExp
match(String path) bool
@Throwing(ArgumentError) @Throwing(PathException)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited